>From 8f7f510961845b90bba9b247adb182520bdcbcc5 Mon Sep 17 00:00:00 2001
From: vlc <vlc@iptv.uplink-netz.ch>
Date: Fri, 13 Jun 2008 05:18:45 +0200
Subject: [PATCH] Change FrontendPoll to also use FE_READ_STATUS to get frontend status.

Certain drivers fail to report the frontend status on frontend events.
When a frontend event without LOCK is received, the state is queried
by a call to FE_READ_STATUS instead.
---
 modules/access/dvb/linux_dvb.c |   15 ++++++++++++++-
 1 files changed, 14 insertions(+), 1 deletions(-)

diff --git a/modules/access/dvb/linux_dvb.c b/modules/access/dvb/linux_dvb.c
index f72eeac..0169a01 100644
--- a/modules/access/dvb/linux_dvb.c
+++ b/modules/access/dvb/linux_dvb.c
@@ -288,7 +288,7 @@ void FrontendPoll( access_t *p_access )
     access_sys_t *p_sys = p_access->p_sys;
     frontend_t * p_frontend = p_sys->p_frontend;
     struct dvb_frontend_event event;
-    fe_status_t i_status, i_diff;
+    fe_status_t i_status, i_status_hack, i_diff;
 
     for( ;; )
     {
@@ -305,6 +305,19 @@ void FrontendPoll( access_t *p_access )
         }
 
         i_status = event.status;
+
+        /* this is a hack */
+        if( !( i_status & FE_HAS_LOCK ) )
+        {
+            if( i_ret = ioctl( p_sys->i_frontend_handle, FE_READ_STATUS, &i_status_hack ) < 0 )
+                msg_Warn( p_access, "reading frontend status failed (%d): %m", i_ret );
+            else if( i_status_hack & FE_HAS_LOCK )
+            {
+                msg_Dbg( p_access, "no frontend status in frontend events." );
+                i_status = i_status_hack;
+            }
+        }
+
         i_diff = i_status ^ p_frontend->i_last_status;
         p_frontend->i_last_status = i_status;
 
-- 
1.5.4.3

